@@ -589,11 +589,11 @@ Ztring& Ztring::From_Local (const char* S)
                 else
                     clear();
             #else //WINDOWS
-                size_t Size=mbstowcs(NULL, S, 0);
+                size_t Size=mbsrtowcs(NULL, &S, 0, NULL);
                 if (Size!=0 && Size!=(size_t)-1)
                 {
                     wchar_t* WideString=new wchar_t[Size+1];
-                    Size=mbstowcs(WideString, S, Size);
+                    Size=mbsrtowcs(WideString, &S, Size, NULL);
                     WideString[Size]=L'\0';
                     assign (WideString);
                     delete[] WideString; //WideString=NULL;
@@ -738,43 +738,50 @@ Ztring& Ztring::From_UUID (const int128u S)
 
 Ztring& Ztring::From_CC4 (const int32u S)
 {
-    std::string S1;
-    S1.append(1, (char)((S&0xFF000000)>>24));
-    S1.append(1, (char)((S&0x00FF0000)>>16));
-    S1.append(1, (char)((S&0x0000FF00)>> 8));
-    S1.append(1, (char)((S&0x000000FF)    ));
-    From_Local(S1.c_str());
-
-    // Validity Test
-    if ( size()==4
-     || (size()==3 && (S&0x000000FF)==0x00000000 && at(0)>=0x20 && at(1)>=0x20 && at(2)>=0x20)
-     || (size()==2 && (S&0x0000FFFF)==0x00000000 && at(0)>=0x20 && at(1)>=0x20)
-     || (size()==1 && (S&0x00FFFFFF)==0x00000000 && at(0)>=0x20))
-        return *this;
-
-    // Not valid, using 0x as fallback
     clear();
-    append(__T("0x"));
-    append(Ztring().From_CC1((int8u)((S&0xFF000000)>>24)));
-    append(Ztring().From_CC1((int8u)((S&0x00FF0000)>>16)));
-    append(Ztring().From_CC1((int8u)((S&0x0000FF00)>> 8)));
-    append(Ztring().From_CC1((int8u)((S&0x000000FF)    )));
+    for (int8s i=(4-1)*8; i>=0; i-=8)
+    {
+        int32u Value=(S&(0xFF<<i))>>i;
+        if (Value<0x20)
+        {
+            if (!i || (i!=24  && !(S&(0xFFFFFFFF>>(32-i)))))
+                return *this; // Trailing 0 are fine
 
+            // Not valid, using 0x as fallback
+            clear();
+            append(__T("0x"));
+            append(Ztring().From_CC1((int8u)((S&0xFF000000)>>24)));
+            append(Ztring().From_CC1((int8u)((S&0x00FF0000)>>16)));
+            append(Ztring().From_CC1((int8u)((S&0x0000FF00)>> 8)));
+            append(Ztring().From_CC1((int8u)((S&0x000000FF)    )));
+            return *this;
+        }
+        append(1, (Char)(Value));
+    }
     return *this;
 }
 
 Ztring& Ztring::From_CC3 (const int32u S)
 {
-    std::string S1;
-    S1.append(1, (char)((S&0x00FF0000)>>16));
-    S1.append(1, (char)((S&0x0000FF00)>> 8));
-    S1.append(1, (char)((S&0x000000FF)>> 0));
-    From_Local(S1.c_str());
-
-    //Test
-    if (empty())
-        assign(__T("(empty)"));
+    clear();
+    for (int8s i=(3-1)*8; i>=0; i-=8)
+    {
+        int32u Value=(S&(0xFF<<i))>>i;
+        if (Value<0x20)
+        {
+            if (!i || (i!=16  && !(S&(0xFFFFFF>>(24-i)))))
+                return *this; // Trailing 0 are fine
 
+            // Not valid, using 0x as fallback
+            clear();
+            append(__T("0x"));
+            append(Ztring().From_CC1((int8u)((S&0x00FF0000)>>16)));
+            append(Ztring().From_CC1((int8u)((S&0x0000FF00)>> 8)));
+            append(Ztring().From_CC1((int8u)((S&0x000000FF)    )));
+            return *this;
+        }
+        append(1, (Char)(Value));
+    }
     return *this;
 }
 
@@ -1305,7 +1312,16 @@ Ztring& Ztring::Date_From_Seconds_1970 (const int32s Value)
 Ztring& Ztring::Date_From_Seconds_1970 (const int64s Value)
 {
     time_t Time=(time_t)Value;
+    #if _POSIX_C_SOURCE >= 1 || _XOPEN_SOURCE || _BSD_SOURCE || _SVID_SOURCE || _POSIX_SOURCE
+    struct tm Gmt_Temp;
+    struct tm *Gmt=gmtime_r(&Time, &Gmt_Temp);
+    #elif defined(_MSC_VER)
+    struct tm Gmt_Temp;
+    errno_t gmtime_s_Result=gmtime_s(&Gmt_Temp , &Time);
+    struct tm* Gmt=gmtime_s_Result?NULL:&Gmt_Temp;
+    #else
     struct tm *Gmt=gmtime(&Time);
+    #endif
     if (!Gmt)
     {
         clear();
@@ -1336,7 +1352,16 @@ Ztring& Ztring::Date_From_Seconds_1970 (const int64s Value)
 Ztring& Ztring::Date_From_Seconds_1970_Local (const int32u Value)
 {
     time_t Time=(time_t)Value;
+    #if _POSIX_C_SOURCE >= 1 || _XOPEN_SOURCE || _BSD_SOURCE || _SVID_SOURCE || _POSIX_SOURCE
+    struct tm Gmt_Temp;
+    struct tm *Gmt=localtime_r(&Time, &Gmt_Temp);
+    #elif defined(_MSC_VER)
+    struct tm Gmt_Temp;
+    errno_t localtime_s_Result=localtime_s(&Gmt_Temp , &Time);
+    struct tm* Gmt=localtime_s_Result?NULL:&Gmt_Temp;
+    #else
     struct tm *Gmt=localtime(&Time);
+    #endif
     Ztring DateT;
     Ztring Date;
     Date+=Ztring::ToZtring((Gmt->tm_year+1900));
@@ -1364,7 +1389,7 @@ Ztring& Ztring::Date_From_String (const char* Value, size_t Value_Size)
     //Only the year
     if (Value_Size<10)
     {
-        From_Local(Value, 0, Value_Size);
+        From_UTF8(Value, 0, Value_Size);
         return *this;
     }
 
@@ -1401,7 +1426,7 @@ Ztring& Ztring::Date_From_String (const char* Value, size_t Value_Size)
 
         assign (ToReturn.c_str());
     #else //ZENLIB_USEWX
-        Ztring DateS; DateS.From_Local(Value, 0, Value_Size);
+        Ztring DateS; DateS.From_UTF8(Value, 0, Value_Size);
         //Unix style formating : exactly 24 bytes (or 25 with 0x0A at the end) and Year is at the end
         if ((DateS.size()==24 || (DateS.size()==25 && DateS[24]==__T('\n'))) && DateS[23]>=__T('0') && DateS[23]<=__T('9') && DateS[21]>=__T('0') && DateS[21]<=__T('9') && DateS[19]==__T(' '))
         {
@@ -1503,7 +1528,7 @@ Ztring& Ztring::Date_From_String (const char* Value, size_t Value_Size)
             append(DateS);
         }
         else
-            From_Local(Value, 0, Value_Size); //Not implemented
+            From_UTF8(Value, 0, Value_Size); //Not implemented
     #endif //ZENLIB_USEWX
     return *this;
 }
@@ -1698,8 +1723,8 @@ std::string Ztring::To_Local () const
                 std::string AnsiString;
                 for (size_t Pos=0; Pos<size(); Pos++)
                 {
-                    int Result_Size=wctomb(Result, operator[](Pos));
-                    if (Result_Size>=0)
+                    size_t Result_Size=wcrtomb(Result, operator[](Pos), 0);
+                    if (Result_Size && Result_Size!=(size_t)-1)
                         AnsiString.append(Result, Result_Size);
                     else
                         AnsiString+='?';
