@@ -131,6 +131,8 @@ ZtringListList &ZtringListList::operator+= (const ZtringListList &Source)
 // Operator =
 ZtringListList &ZtringListList::operator= (const ZtringListList &Source)
 {
+    if (this == &Source)
+        return *this;
     clear();
 
     reserve(Source.size());
@@ -288,17 +290,40 @@ void ZtringListList::Write(const Ztring &ToWrite)
     if (ToWrite.empty())
         return;
 
+    //Detecting carriage return format
+    Ztring Separator0;
+    if (Separator[0]==EOL)
+    {
+        size_t CarriageReturn_Pos=ToWrite.find_first_of(__T("\r\n"));
+        if (CarriageReturn_Pos!=string::npos)
+        {
+            if (ToWrite[CarriageReturn_Pos]==__T('\r'))
+            {
+                if (CarriageReturn_Pos+1<ToWrite.size() && ToWrite[CarriageReturn_Pos+1]==__T('\n'))
+                    Separator0=__T("\r\n");
+                else
+                    Separator0=__T("\r");
+            }
+            else
+                Separator0=__T("\n");
+        }
+        else
+            Separator0=Separator[0];
+    }
+    else
+        Separator0=Separator[0];
+
     size_t l=ToWrite.size();
     size_t i=0;
     bool q=false; //In quotes
     size_t Quote_Size=Quote.size();
-    size_t Separator0_Size=Separator[0].size();
+    size_t Separator0_Size=Separator0.size();
     size_t Separator1_Size=Separator[1].size();
     size_t x=0, y=0;
     while (i<l)
     {
         //Quote
-        if (i+Quote_Size<=l)
+        if (Quote_Size && i+Quote_Size<=l)
         {
             bool IsQuote=true;
             for (size_t j=0; j<Quote_Size; j++)
@@ -343,7 +368,7 @@ void ZtringListList::Write(const Ztring &ToWrite)
                 bool IsSeparator0=true;
                 for (size_t j=0; j<Separator0_Size; j++)
                 {
-                    if (ToWrite[i+j]!= Separator[0][j])
+                    if (ToWrite[i+j]!= Separator0[j])
                     {
                         IsSeparator0=false;
                         break;
@@ -384,7 +409,11 @@ void ZtringListList::Write(const Ztring &ToWrite)
             size_t PreviousSize=size();
             resize(y+1);
             for (size_t j=0; j<=y; j++)
+            {
                 operator[](j).Separator_Set(0, Separator[1]);
+                operator[](j).Quote_Set(Quote);
+                operator[](j).Max_Set(0, Max[1]);
+            }
         }
         ZtringList& Line=operator[](y);
         if (x>=Line.size())
@@ -575,7 +604,7 @@ ZtringListList ZtringListList::SubSheet (const Ztring &ToFind, size_type Pos1, s
 // Separator
 void ZtringListList::Separator_Set (size_type Level, const Ztring &NewSeparator)
 {
-    if (Level>1)
+    if (NewSeparator.empty() || Level>1)
         return;
 
     Separator[Level]=NewSeparator;
