@@ -100,7 +100,7 @@ int128::int128 (const char * sz) throw ()
             ++i;
         };
     };
-    const unsigned int len = strlen(sz);
+    const size_t len = strlen(sz);
     for (; i < len; ++i) {
         unsigned int n = 0;
         if (sz [i] >= '0' && sz [i] <= (('0' + (int) radix) < '9'?('0' + (int) radix):'9')) //if (sz [i] >= '0' && sz [i] <= (('0' + (int) radix) <? '9'))
